clear
set mem 100m
cd "SET WORKING DIRECTORY"
use "replication.dta", clear
cd tables
set more 1
tsset instcode year
gen chperf=0
replace chperf=1 if ctype==1 | ctype==5
gen chnperf=0
replace chnperf=1 if ctype==2 | ctype==4 | ctype==6| ctype==8 | ctype==10
replace chperf=. if year<1997
replace chnperf=. if year<1997

set seed 1000

replace wpct=wins/(wins+losses+ties)

sort instcode year

* gen conference win percentage
gen cwpct=cwins/(cwins+closses+cties)
replace cwpct=wpct if cwins==. | closses==.


forvalues i=1/10{
gen l`i'wpct=l`i'.wpct
gen l`i'bowl=l`i'.wpct
}
egen wpct2=rmean(l1wpct l2wpct)
egen wpct3=rmean(l1wpct l2wpct l3wpct)
egen wpct4=rmean(l1wpct l2wpct l3wpct l4wpct)
egen wpct5=rmean(l1wpct l2wpct l3wpct l4wpct l5wpct)
egen wpct6=rmean(l1wpct l2wpct l3wpct l4wpct l5wpct l6wpct)
egen wpct7=rmean(l1wpct l2wpct l3wpct l4wpct l5wpct l6wpct l7wpct )
egen wpct8=rmean(l1wpct l2wpct l3wpct l4wpct l5wpct l6wpct l7wpct l8wpct)
egen wpct9=rmean(l1wpct l2wpct l3wpct l4wpct l5wpct l6wpct l7wpct l8wpct l9wpct)
egen wpct10=rmean(l1wpct l2wpct l3wpct l4wpct l5wpct l6wpct l7wpct l8wpct l9wpct l10wpct)
egen wpctL=rmean(l2wpct l3wpct l4wpct l5wpct l6wpct l7wpct l8wpct l9wpct l10wpct)

gen expenses_ln=ln(expenses)

***LAGS
gen lwpct=l.wpct
forvalues i=1/10{
gen lwpctD`i'=l.wpct-l.wpct`i'
}
gen lcwpct=l.cwpct
gen lbowl=l.bowl
gen lbowlwin=l.bowlwin
gen lsos=l.sos
gen lctenure=l.ctenure
gen lstaravg=l.staravg
gen lexpenses=l.expenses
gen lexpenses_ln=l.expenses_ln
gen lbowl10=l.bowl+l2.bowl+l3.bowl+l4.bowl+l5.bowl+l6.bowl+l7.bowl+l8.bowl+l9.bowl+l10.bowl

* lag interactions
foreach i in l1wpct lwpctD5 lwpctD10 lcwpct lbowl {
gen lctenureX`i'=lctenure*`i'
}

*Expenses differences 
gen diff_expenses=expenses-lexpenses
gen diff_expenses_ln=ln(diff_expenses)


***FORWARD 
forvalues i=1/4 {
gen f`i'wpct=f`i'.wpct
gen f`i'cwpct=f.cwpct
gen f`i'bowl=f`i'.bowl
gen f`i'ctenure=f`i'.ctenure

gen d`i'wpct=f`i'.wpct-l1wpct
}
gen d0wpct=wpct-l1wpct

sort instcode year
gen caseid=_n

*** GENERATE PROPENSITY SCORES
pscore chperf wpctL l1wpct lwpctD5 lwpctD10 lcwpct lbowl lctenure if year>1996, pscore(propscore) comsup blockid(blocks) numblo(4)

drop if year<=1996
cem l1wpct (#10) lwpctD10 (#10) lbowl (0 1), treatment(chperf) autocuts(fd) 


** N-Neighbor MATCHING
attnd l1wpct chperf, pscore(propscore) comsup blockid(blocks) matchvar(insamplend) matchdta(attnd) id(caseid) 
sort caseid
merge caseid using "attnd.dta"
sort propscore
list team year propscore if insamplend==1 & chperf==0, sep(0)
list team year propscore if insamplend==1 & chperf==1, sep(0)


** GENERATE BLOCK IDs and BLOCK x CHANGE INTERACTIONS
gen pscoreX=propscore*chperf
tab blocks, gen(block)
gen chperfB1=chperf*block1
gen chperfB2=chperf*block2
gen chperfB3=chperf*block3
gen chperfB4=chperf*block4
gen chnperfB1=chnperf*block1
gen chnperfB2=chnperf*block2
gen chnperfB3=chnperf*block3
gen chnperfB4=chnperf*block4


** LABEL ALL VARIABLES
label var wpct "Win Percentage (T)"
label var chperf "Performance-based Replacement (1=yes)"
label var chnperf "Non-Performance-based Replacement (1=yes)"
label var propscore "Propensity Score"
label var pscoreX "Propensity Score x PB Change"
label var block2 "Block 2 (1=yes)"
label var block3 "Block 3 (1=yes)"
label var block4 "Block 4 (1=yes)"
label var chperfB2 "Block 2 x PB Change"
label var chperfB3 "Block 3 x PB Change"
label var chperfB4 "Block 4 x PB Change"
label var chnperfB2 "Block 2 x Non-PB Change"
label var chnperfB3 "Block 3 x Non-PB Change"
label var chnperfB4 "Block 4 x Non-PB Change"
label var l1wpct "Win Percentage (T-1)"
label var wpctL "Win Percentage (T-2 to T-10)"

label var lwpctD5 "Win Pct. Differential (5 year; T-1)"
label var lwpctD10 "Win Pct. Differential (10 year; T-1)"
label var lcwpct "Conf. Win Percentage (T-1)"
label var lbowl "Bowl Appearance (T-1)"
label var lsos "Strength of Schedule (T-1)"
label var lctenure "Coach Tenure (T-1)" 
label var expenses_ln "Football Expenses (Logged; T)" 
label var lexpenses_ln "Football Expenses (Logged; T-1)" 
label var diff_expenses "Change in Athletic Expenses" 
label var diff_expenses_ln "Change in Expenses (Logged)" 
label var lstaravg "Average Rival.com Star Ratings (T-1)"
label var star5 "Number of 5 Star Recruits (T)"
label var star4 "Number of 4 Star Recruits (T)"
label var star3 "Number of 3 Star Recruits (T)"
label var staravg "Average Rival.com Star Ratings (T)"
label var year "Year"
label var f1wpct "Win Percentage (T+1)"
label var f2wpct "Win Percentage (T+2)"
label var f3wpct "Win Percentage (T+3)"
label var f4wpct "Win Percentage (T+4)"

*** TABLE A1: SUMMARY OF CHANGES BY YEAR
table year if year>1996, c(freq sum cchange sum chperf sum chnperf)

*** TABLE A2: PSCORE MODEL
probit chperf l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure if year>1996
outreg using "A2_propmodel.out", bracket 3aster rdec(3) se replace

*** FIGURE S1: HISTOGRAMS OF PROPENSITY SCORES
hist propscore if chperf==0, xlabel(0(.05).55) xscale(range(0 .55))width(.0125) start(0) xtitle(Propensity Score) legend(size(small)) graphregion(fcolor(white) lcolor(none)) plotregion(fcolor(white)) fcolor(gs7) lcolor(black) lwidth(thin) title("No Change")
graph export "A1_histogram_nochange.png", as(png) replace
hist propscore if chperf==1, xlabel(0(.05).55) xscale(range(0 .55))width(.0125) start(0) xtitle(Propensity Score) legend(size(small)) graphregion(fcolor(white) lcolor(none)) plotregion(fcolor(white)) fcolor(gs7) lcolor(black) lwidth(thin) title("Change")
graph export "A1_histogram_change.png", as(png) replace

************************************************
************* MAIN ANALYSIS ********************
************************************************
*** TABLE 1: SUMMARY STATS / OVERALL BALANCE
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if propscore!=. & chperf==0 using "T1_balance.out", bracket replace ctitle(No Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if propscore!=. & chperf==1 using "T1_balance", bracket append ctitle(Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==0 & comsup==1 using "T1_balance", bracket append ctitle(Common Support: No Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==1 & comsup==1 using "T1_balance", bracket append ctitle(Common Support: Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==0 & blocks==1 using "T1_balance", bracket append ctitle(Block 1: No Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==1 & blocks==1 using "T1_balance", bracket append ctitle(Block 1: Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==0 & blocks==2 using "T1_balance", bracket append ctitle(Block 2: No Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==1 & blocks==2 using "T1_balance", bracket append ctitle(Block 2: Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==0 & blocks==3 using "T1_balance", bracket append ctitle(Block 3: No Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==1 & blocks==3 using "T1_balance", bracket append ctitle(Block 3: Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==0 & blocks==4 using "T1_balance", bracket append ctitle(Block 4: No Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==1 & blocks==4 using "T1_balance", bracket append ctitle(Block 4: Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==0 & insamplend==1 using "T1_balance", bracket append ctitle(N-N Matching: No Change)
outsum l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure year propscore if chperf==1 & insamplend==1 using "T1_balance", bracket append ctitle(N-N Matching: Change)

*** FIGURE 1: TREATMENT EFFECTS FIGURE DATA 
matrix drop _all
set more 1
forvalues i=1/4{
atts l1wpct chperf if blocks==`i', pscore(propscore) blockid(blocks)
matrix attwpct0b`i'=r(atts)\r(seatts)\invttail((r(ncs)+r(nts)),.05)
atts d0wpct chperf if blocks==`i', pscore(propscore) blockid(blocks)
matrix attwpct1b`i'=r(atts)\r(seatts)\invttail((r(ncs)+r(nts)),.05)
atts d1wpct chperf if blocks==`i' & f1ctenure!=., pscore(propscore) blockid(blocks)
matrix attwpct2b`i'=r(atts)\r(seatts)\invttail((r(ncs)+r(nts)),.05)
atts d2wpct chperf if blocks==`i' & f2ctenure!=., pscore(propscore) blockid(blocks)
matrix attwpct3b`i'=r(atts)\r(seatts)\invttail((r(ncs)+r(nts)),.05)
atts d3wpct chperf if blocks==`i' & f3ctenure!=., pscore(propscore) blockid(blocks)
matrix attwpct4b`i'=r(atts)\r(seatts)\invttail((r(ncs)+r(nts)),.05)
atts d4wpct chperf if blocks==`i' & f4ctenure!=., pscore(propscore) blockid(blocks)
matrix attwpct4b`i'=r(atts)\r(seatts)\invttail((r(ncs)+r(nts)),.05)
matrix attwpctB`i'=attwpct0b`i',attwpct1b`i',attwpct2b`i',attwpct3b`i',attwpct4b`i',attwpct4b`i'
}
matrix attwpct=attwpctB1\attwpctB2\attwpctB3\attwpctB4
matrix list attwpct

*** TABLE 2: NEAREST NEIGHBOR ANALYSIS
reg d0wpct chperf propscore pscoreX lwpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure if insamplend==1, cluster(instcode)
outreg using "T2_nearestneighbor.out", bracket se replace 3aster rdec(3) 
reg d0wpct chperf block2 block3 block4 chperfB2 chperfB3 chperfB4 lwpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure if insamplend==1, cluster(instcode)
outreg using "T2_nearestneighbor.out", bracket se append 3aster rdec(3) 
reg d1wpct chperf block2 block3 block4 chperfB2 chperfB3 chperfB4 lwpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure if insamplend==1, cluster(instcode)
outreg using "T2_nearestneighbor.out", bracket se append 3aster rdec(3) 
reg d2wpct chperf block2 block3 block4 chperfB2 chperfB3 chperfB4 lwpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure if insamplend==1, cluster(instcode)
outreg using "T2_nearestneighbor.out", bracket se append 3aster rdec(3) 
reg d3wpct chperf block2 block3 block4 chperfB2 chperfB3 chperfB4 lwpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure if insamplend==1, cluster(instcode)
outreg using "T2_nearestneighbor.out", bracket se append 3aster rdec(3) 


******* WEIGHTED ANALYSIS
set more 1
gen weight=chperf+((1-chperf)*propscore/(1-propscore))

*** TABLE A3: DEMONSTRATE WEIGHTED BALANCE
reg l1wpct chperf [pw=weight] if comsup==1, cluster(instcode)
outreg chperf using "A3_w_balance.out", se bracket replace 3aster rdec(3)
foreach i in wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure {
reg `i' chperf [pw=weight] if comsup==1, cluster(instcode)
outreg chperf using "A3_w_balance.out", se bracket append 3aster rdec(3)
}

*** TABLE T3: WEIGHTED ANALYSIS
*PLACEHOLDER MODEL TO keep variables in a sensible order for the other models
reg wpct chperf chnperf propscore pscoreX block2 block3 block4 chperfB2 chperfB3 chperfB4 chnperfB2 chnperfB3 chnperfB4 l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure [aweight=weight] if comsup==1, cluster(instcode) 
outreg using "T3_weighted.out", bracket se replace 3aster rdec(3)

reg wpct chperf propscore pscoreX l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure [pweight=weight] if comsup==1, cluster(instcode)
outreg using "T3_weighted.out", bracket se append 3aster rdec(3)
reg wpct chperf block2 block3 block4 chperfB2 chperfB3 chperfB4 l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure [pweight=weight] if comsup==1, cluster(instcode)
outreg using "T3_weighted.out", bracket se append 3aster rdec(3)

forvalues i=1/3{
reg f`i'wpct chperf block2 block3 block4 chperfB2 chperfB3 chperfB4 l1wpct wpctL lwpctD5 lwpctD10 lcwpct lbowl lctenure [pweight=weight] if comsup==1, cluster(instcode)
outreg using "T3_weighted.out", bracket label se append 3aster rdec(3)
}


************************************************************************
****** ADDITIONAL ANALYSIS FOR SUPPLEMENTARY ANALYSIS DOCUMENT *********
************************************************************************
*** FIGURE A2: CONFERENCE WIN % EFFECTS
matrix drop _all
set more 1
forvalues i=1/4{
atts lcwpct chperf if blocks==`i', pscore(propscore) blockid(blocks)
matrix attwpct0b`i'=(r(atts)\r(seatts)\r(tsatts))
atts cwpct chperf if blocks==`i', pscore(propscore) blockid(blocks)
matrix attwpct1b`i'=(r(atts)\r(seatts)\r(tsatts))
atts f1cwpct chperf if blocks==`i' & f1ctenure!=., pscore(propscore) blockid(blocks)
matrix attwpct2b`i'=(r(atts)\r(seatts)\r(tsatts))
atts f2cwpct chperf if blocks==`i' & f2ctenure!=., pscore(propscore) blockid(blocks)
matrix attwpct3b`i'=(r(atts)\r(seatts)\r(tsatts))
atts f3cwpct chperf if blocks==`i' & f3ctenure!=., pscore(propscore) blockid(blocks)
matrix attwpct4b`i'=(r(atts)\r(seatts)\r(tsatts))
atts f4cwpct chperf if blocks==`i' & f4ctenure!=., pscore(propscore) blockid(blocks)
matrix attwpct4b`i'=(r(atts)\r(seatts)\r(tsatts))
}
matrix attwpctB1=attwpct0b1,attwpct1b1,attwpct2b1,attwpct3b1,attwpct4b1,attwpct4b1
matrix attwpctB2=attwpct0b2,attwpct1b2,attwpct2b2,attwpct3b2,attwpct4b2,attwpct4b2
matrix attwpctB3=attwpct0b3,attwpct1b3,attwpct2b3,attwpct3b3,attwpct4b3,attwpct4b3
matrix attwpctB4=attwpct0b4,attwpct1b4,attwpct2b4,attwpct3b4,attwpct4b4,attwpct4b4
matrix attwpct=attwpctB1\attwpctB2\attwpctB3\attwpctB4
matrix list attwpct

*** TABLE A4: VARIANCE 
robvar wpct if comsup, by(chperf)
robvar wpct if blocks==1, by(chperf)
robvar wpct if blocks==2, by(chperf)
robvar wpct if blocks==3, by(chperf)
robvar wpct if blocks==4, by(chperf)

*** TABLE A5: RECRUITING STATS/FOOTBALL EXPENSES
outsum lstaravg staravg lexpenses_ln expenses_ln diff_expenses_ln if chperf==0 & blocks==1 using "A5_recruitstats.out", bracket replace ctitle(Block 1: No Change)
outsum lstaravg staravg lexpenses_ln expenses_ln diff_expenses_ln if chperf==1 & blocks==1 using "A5_recruitstats", bracket append ctitle(Block 1: Change)
outsum lstaravg staravg lexpenses_ln expenses_ln diff_expenses_ln if chperf==0 & blocks==2 using "A5_recruitstats", bracket append ctitle(Block 2: No Change)
outsum lstaravg staravg lexpenses_ln expenses_ln diff_expenses_ln if chperf==1 & blocks==2 using "A5_recruitstats", bracket append ctitle(Block 2: Change)
outsum lstaravg staravg lexpenses_ln expenses_ln diff_expenses_ln if chperf==0 & blocks==3 using "A5_recruitstats", bracket append ctitle(Block 3: No Change)
outsum lstaravg staravg lexpenses_ln expenses_ln diff_expenses_ln if chperf==1 & blocks==3 using "A5_recruitstats", bracket append ctitle(Block 3: Change)
outsum lstaravg staravg lexpenses_ln expenses_ln diff_expenses_ln if chperf==0 & blocks==4 using "A5_recruitstats", bracket append ctitle(Block 4: No Change)
outsum lstaravg staravg lexpenses_ln expenses_ln diff_expenses_ln if chperf==1 & blocks==4 using "A5_recruitstats", bracket append ctitle(Block 4: Change)

forvalues i=1/4{
ttest lstaravg if blocks==`i', by(chperf)
ttest staravg if blocks==`i', by(chperf)
ttest lexpenses_ln if blocks==`i', by(chperf)
ttest expenses_ln if blocks==`i', by(chperf)
ttest diff_expenses_ln if blocks==`i', by(chperf)
}


